@@ -3,30 +3,33 @@ package scrape
 import (
 	"context"
 	"fmt"
+	"log/slog"
 	"net/url"
 	"reflect"
 	"slices"
 	"sync"
 	"time"
 
-	go_kit_log "github.com/go-kit/log"
-
 	"github.com/alecthomas/units"
 	client_prometheus "github.com/prometheus/client_golang/prometheus"
 	config_util "github.com/prometheus/common/config"
 	"github.com/prometheus/common/model"
 	"github.com/prometheus/prometheus/config"
 	"github.com/prometheus/prometheus/discovery/targetgroup"
+	"github.com/prometheus/prometheus/model/exemplar"
 	"github.com/prometheus/prometheus/model/histogram"
 	"github.com/prometheus/prometheus/model/labels"
+	"github.com/prometheus/prometheus/model/metadata"
 	"github.com/prometheus/prometheus/scrape"
 	"github.com/prometheus/prometheus/storage"
+	promlogging "github.com/prometheus/prometheus/util/logging"
 
 	"github.com/grafana/alloy/internal/component"
 	component_config "github.com/grafana/alloy/internal/component/common/config"
 	"github.com/grafana/alloy/internal/component/discovery"
 	"github.com/grafana/alloy/internal/component/prometheus"
 	"github.com/grafana/alloy/internal/featuregate"
+	"github.com/grafana/alloy/internal/runtime/logging"
 	"github.com/grafana/alloy/internal/runtime/logging/level"
 	"github.com/grafana/alloy/internal/service/cluster"
 	"github.com/grafana/alloy/internal/service/http"
@@ -34,9 +37,6 @@ import (
 	"github.com/grafana/alloy/internal/service/livedebugging"
 	"github.com/grafana/alloy/internal/useragent"
 	"github.com/grafana/alloy/internal/util"
-	"github.com/prometheus/prometheus/model/exemplar"
-	"github.com/prometheus/prometheus/model/metadata"
-	"github.com/prometheus/prometheus/util/logging"
 )
 
 func init() {
@@ -121,6 +121,25 @@ type Arguments struct {
 	// It is invalid to set both EnableProtobufNegotiation and ScrapeProtocols.
 	// TODO: https://github.com/grafana/alloy/issues/878: Remove this option.
 	EnableProtobufNegotiation bool `alloy:"enable_protobuf_negotiation,attr,optional"`
+	// The validation scheme to use for metric names.
+	MetricNameValidationScheme string `alloy:"metric_name_validation_scheme,attr,optional"`
+	// The escaping scheme to use for metric names.
+	MetricNameEscapingScheme string `alloy:"metric_name_escaping_scheme,attr,optional"`
+	// The fallback protocol to use if the target does not provide a valid Content-Type header.
+	ScrapeFallbackProtocol string `alloy:"scrape_fallback_protocol,attr,optional"`
+	// Whether to convert classic histograms with buckets to native histograms
+	// with custom buckets (NHCB). False by default.
+	ConvertClassicHistogramsToNHCB bool `alloy:"convert_classic_histograms_to_nhcb,attr,optional"`
+	// Whether compression is enabled for the scrape. True by default.
+	EnableCompression bool `alloy:"enable_compression,attr,optional"`
+	// If there are more than this many buckets in a native histogram,
+	// buckets will be merged to stay within the limit. Disabled when set to zero.
+	NativeHistogramBucketLimit uint `alloy:"native_histogram_bucket_limit,attr,optional"`
+	// If the growth factor of one bucket to the next is smaller than this,
+	// buckets will be merged to stay within the limit. Disabled when set zero.
+	NativeHistogramMinBucketFactor float64 `alloy:"native_histogram_min_bucket_factor,attr,optional"`
+	// Whether the metric metadata should be passed to the downstream components.
+	HonorMetadata bool `alloy:"honor_metadata,attr,optional"`
 
 	Clustering cluster.ComponentBlock `alloy:"clustering,block,optional"`
 }
@@ -137,7 +156,14 @@ func (arg *Arguments) SetToDefault() {
 		ScrapeInterval:           1 * time.Minute,  // From config.DefaultGlobalConfig
 		ScrapeTimeout:            10 * time.Second, // From config.DefaultGlobalConfig
 		ScrapeProtocols:          slices.Clone(defaultScrapeProtocols),
-		ScrapeNativeHistograms:   true,
+		ScrapeFallbackProtocol:   string(config.PrometheusText0_0_4), // Use the same fallback protocol as Prometheus v2
+		ScrapeNativeHistograms:   false,
+		// NOTE: the MetricNameEscapingScheme depends on this, so its default must be set in Validate() function.
+		MetricNameValidationScheme:     config.LegacyValidationConfig,
+		ConvertClassicHistogramsToNHCB: false,
+		EnableCompression:              true,
+		NativeHistogramBucketLimit:     0,
+		NativeHistogramMinBucketFactor: 0,
 	}
 }
 
@@ -156,6 +182,21 @@ func (arg *Arguments) Validate() error {
 		// For backwards-compatibility, if EnableProtobufNegotiation is set to true, the ScrapeProtocols are set to
 		// [PrometheusProto, OpenMetricsText1.0.0, OpenMetricsText0.0.1, PrometheusText0.0.4].
 		arg.ScrapeProtocols = slices.Clone(defaultNativeHistogramScrapeProtocols)
+		// In previous Prometheus versions, EnableProtobufNegotiation would also enable native histogram scraping.
+		// This is no longer the case, so we need to explicitly enable it here.
+		arg.ScrapeNativeHistograms = true
+	}
+
+	if arg.ScrapeNativeHistograms {
+		// When scrape_native_histograms is set to true, the default scrape protocols are overridden to
+		// Proto-first scrape protocols, like in upstream Prometheus.
+		if reflect.DeepEqual(arg.ScrapeProtocols, defaultScrapeProtocols) {
+			arg.ScrapeProtocols = slices.Clone(defaultNativeHistogramScrapeProtocols)
+		}
+
+		if !slices.Contains(arg.ScrapeProtocols, string(config.PrometheusProto)) {
+			return fmt.Errorf("scrape_native_histograms is set to true, but PrometheusProto is not in scrape_protocols")
+		}
 	}
 
 	// Validate scrape protocols
@@ -171,6 +212,36 @@ func (arg *Arguments) Validate() error {
 		existing[p] = struct{}{}
 	}
 
+	if arg.ScrapeFallbackProtocol != "" {
+		promSP := config.ScrapeProtocol(arg.ScrapeFallbackProtocol)
+		if err := promSP.Validate(); err != nil {
+			return fmt.Errorf("invalid scrape_fallback_protocol %q: %w", arg.ScrapeFallbackProtocol, err)
+		}
+	}
+
+	switch arg.MetricNameValidationScheme {
+	case config.UTF8ValidationConfig, config.LegacyValidationConfig:
+	default:
+		return fmt.Errorf("invalid metric_name_validation_scheme %q: must be either %q or %q", arg.MetricNameValidationScheme, config.UTF8ValidationConfig, config.LegacyValidationConfig)
+	}
+
+	switch arg.MetricNameEscapingScheme {
+	case "":
+		if arg.MetricNameValidationScheme == config.LegacyValidationConfig {
+			arg.MetricNameEscapingScheme = model.EscapeUnderscores
+		} else {
+			arg.MetricNameEscapingScheme = model.AllowUTF8
+		}
+	case model.AllowUTF8, model.EscapeUnderscores, model.EscapeDots, model.EscapeValues:
+	default:
+		supportedValues := []string{model.AllowUTF8, model.EscapeUnderscores, model.EscapeDots, model.EscapeValues}
+		return fmt.Errorf("invalid metric_name_escaping_scheme: %q, supported values: %v", arg.MetricNameEscapingScheme, supportedValues)
+	}
+
+	if arg.MetricNameEscapingScheme == model.AllowUTF8 && arg.MetricNameValidationScheme != config.UTF8ValidationConfig {
+		return fmt.Errorf("metric_name_escaping_scheme cannot be set to 'allow-utf-8' while metric_name_validation_scheme is not set to 'utf8'")
+	}
+
 	// We must explicitly Validate because HTTPClientConfig is squashed and it won't run otherwise
 	return arg.HTTPClientConfig.Validate()
 }
@@ -193,10 +264,11 @@ type Component struct {
 	movedTargetsCounter client_prometheus.Counter
 	unregisterer        util.Unregisterer
 
-	mut        sync.RWMutex
-	args       Arguments
-	scraper    *scrape.Manager
-	appendable *prometheus.Fanout
+	mut             sync.RWMutex
+	args            Arguments
+	scraper         *scrape.Manager
+	appendable      *prometheus.Fanout
+	firstUpdateDone bool
 
 	dtMutex            sync.Mutex
 	distributedTargets *discovery.DistributedTargets
@@ -234,13 +306,27 @@ func New(o component.Options, args Arguments) (*Component, error) {
 	}
 	ls := service.(labelstore.LabelStore)
 
-	alloyAppendable := prometheus.NewFanout(args.ForwardTo, o.ID, o.Registerer, ls)
+	if args.HonorMetadata && !o.MinStability.Permits(featuregate.StabilityExperimental) {
+		return nil, fmt.Errorf("honor_metadata is an experimental feature, and must be enabled by setting the stability.level flag to experimental")
+	}
+
+	var metadataStore prometheus.UpdateableMetadataStore
+	if args.HonorMetadata {
+		metadataStore = prometheus.NewMetadataStore()
+	} else {
+		metadataStore = prometheus.NoopMetadataStore{}
+	}
+
+	alloyAppendable := prometheus.NewFanout(args.ForwardTo, o.ID, o.Registerer, ls, metadataStore)
 	scrapeOptions := &scrape.Options{
+		// NOTE: This is not Update()-able.
 		ExtraMetrics: args.ExtraMetrics,
 		HTTPClientOptions: []config_util.HTTPClientOption{
 			config_util.WithDialContextFunc(httpData.DialFunc),
 		},
+		// NOTE: This is not Update()-able.
 		EnableNativeHistogramsIngestion: args.ScrapeNativeHistograms,
+		AppendMetadata:                  args.HonorMetadata,
 	}
 
 	unregisterer := util.WrapWithUnregisterer(o.Registerer)
@@ -276,8 +362,8 @@ func New(o component.Options, args Arguments) (*Component, error) {
 
 	scraper, err := scrape.NewManager(
 		scrapeOptions,
-		o.Logger,
-		func(s string) (go_kit_log.Logger, error) { return logging.NewJSONFileLogger(s) },
+		slog.New(logging.NewSlogGoKitHandler(c.opts.Logger)),
+		func(s string) (*promlogging.JSONFileLogger, error) { return promlogging.NewJSONFileLogger(s) },
 		interceptor,
 		unregisterer)
 	if err != nil {
@@ -381,14 +467,31 @@ func (c *Component) Update(args component.Arguments) error {
 
 	c.mut.Lock()
 	defer c.mut.Unlock()
+
+	// Some fields are not updateable at runtime - only allow them when Update()
+	// is called for the first time from New().
+	if !c.firstUpdateDone {
+		c.firstUpdateDone = true
+	} else {
+		if c.args.ScrapeNativeHistograms != newArgs.ScrapeNativeHistograms {
+			return fmt.Errorf("scrape_native_histograms cannot be updated at runtime")
+		}
+		if c.args.ExtraMetrics != newArgs.ExtraMetrics {
+			return fmt.Errorf("extra_metrics cannot be updated at runtime")
+		}
+	}
+
 	c.args = newArgs
 
 	c.appendable.UpdateChildren(newArgs.ForwardTo)
 
+	promConfig, err := config.Load("", slog.New(logging.NewSlogGoKitHandler(c.opts.Logger)))
+	if err != nil {
+		return fmt.Errorf("error loading blank prometheus config: %w", err)
+	}
 	sc := getPromScrapeConfigs(c.opts.ID, newArgs)
-	err := c.scraper.ApplyConfig(&config.Config{
-		ScrapeConfigs: []*config.ScrapeConfig{sc},
-	})
+	promConfig.ScrapeConfigs = []*config.ScrapeConfig{sc}
+	err = c.scraper.ApplyConfig(promConfig)
 	if err != nil {
 		return fmt.Errorf("error applying scrape configs: %w", err)
 	}
@@ -436,7 +539,7 @@ func getPromScrapeConfigs(jobName string, c Arguments) *config.ScrapeConfig {
 	dec.HonorTimestamps = c.HonorTimestamps
 	dec.TrackTimestampsStaleness = c.TrackTimestampsStaleness
 	dec.Params = c.Params
-	dec.ScrapeClassicHistograms = c.ScrapeClassicHistograms
+	dec.AlwaysScrapeClassicHistograms = c.ScrapeClassicHistograms
 	dec.ScrapeInterval = model.Duration(c.ScrapeInterval)
 	dec.ScrapeTimeout = model.Duration(c.ScrapeTimeout)
 	dec.ScrapeFailureLogFile = c.ScrapeFailureLogFile
@@ -458,6 +561,16 @@ func getPromScrapeConfigs(jobName string, c Arguments) *config.ScrapeConfig {
 
 	// HTTP scrape client settings
 	dec.HTTPClientConfig = *c.HTTPClientConfig.Convert()
+
+	dec.MetricNameValidationScheme = c.MetricNameValidationScheme
+	dec.MetricNameEscapingScheme = c.MetricNameEscapingScheme
+	dec.ScrapeFallbackProtocol = config.ScrapeProtocol(c.ScrapeFallbackProtocol)
+	convertToNHCB := c.ConvertClassicHistogramsToNHCB
+	dec.ConvertClassicHistogramsToNHCB = &convertToNHCB
+	dec.EnableCompression = c.EnableCompression
+	dec.NativeHistogramBucketLimit = c.NativeHistogramBucketLimit
+	dec.NativeHistogramMinBucketFactor = c.NativeHistogramMinBucketFactor
+
 	return &dec
 }
 
@@ -488,12 +601,12 @@ func BuildTargetStatuses(targets map[string][]*scrape.Target) []TargetStatus {
 				lastError = st.LastError().Error()
 			}
 			if st != nil {
-				lb := labels.NewScratchBuilder(0)
+				lb := labels.NewBuilder(labels.EmptyLabels())
 				res = append(res, TargetStatus{
 					JobName:            job,
 					URL:                st.URL().String(),
 					Health:             string(st.Health()),
-					Labels:             st.Labels(&lb).Map(),
+					Labels:             st.Labels(lb).Map(),
 					LastError:          lastError,
 					LastScrape:         st.LastScrape(),
 					LastScrapeDuration: st.LastScrapeDuration(),
@@ -520,7 +633,6 @@ func (c *Component) populatePromLabels(targets []discovery.Target, jobName strin
 			promTargets, errs := scrape.TargetsFromGroup(
 				tg,
 				getPromScrapeConfigs(jobName, args),
-				false,                                /* noDefaultScrapePort - always false in this component */
 				make([]*scrape.Target, len(targets)), /* targets slice to reuse */
 				labels.NewBuilder(labels.EmptyLabels()),
 			)
