@@ -63,6 +63,8 @@ const (
 	MetricSourceCloudFoundry
 	MetricSourceJenkins
 	MetricSourceGPU
+	MetricSourceWlan
+	MetricSourceWindowsCertificateStore
 
 	// Python Checks
 	MetricSourceZenohRouter
@@ -316,6 +318,17 @@ const (
 	MetricSourceSilverstripeCMS
 	MetricSourceAnecdote
 	MetricSourceSonatypeNexus
+	MetricSourceAltairPBSPro
+	MetricSourceFalco
+	MetricSourceKrakenD
+	MetricSourceKuma
+	MetricSourceLiteLLM
+	MetricSourceLustre
+	MetricSourceProxmox
+	MetricSourceResilience4j
+	MetricSourceSupabase
+	MetricSourceKeda
+	MetricSourceDuckdb
 
 	// OpenTelemetry Collector receivers
 	MetricSourceOpenTelemetryCollectorUnknown
@@ -361,6 +374,21 @@ const (
 	MetricSourceOpenTelemetryCollectorBigipReceiver
 	MetricSourceOpenTelemetryCollectorChronyReceiver
 	MetricSourceOpenTelemetryCollectorCouchdbReceiver
+
+	// Serverless
+	MetricSourceServerless
+	MetricSourceAwsLambdaCustom
+	MetricSourceAwsLambdaEnhanced
+	MetricSourceAwsLambdaRuntime
+	MetricSourceAzureContainerAppCustom
+	MetricSourceAzureContainerAppEnhanced
+	MetricSourceAzureContainerAppRuntime
+	MetricSourceAzureAppServiceCustom
+	MetricSourceAzureAppServiceEnhanced
+	MetricSourceAzureAppServiceRuntime
+	MetricSourceGoogleCloudRunCustom
+	MetricSourceGoogleCloudRunEnhanced
+	MetricSourceGoogleCloudRunRuntime
 )
 
 // String returns a string representation of MetricSource
@@ -942,6 +970,28 @@ func (ms MetricSource) String() string {
 		return "celery"
 	case MetricSourceInfiniband:
 		return "infiniband"
+	case MetricSourceAltairPBSPro:
+		return "altair_pbs_pro"
+	case MetricSourceFalco:
+		return "falco"
+	case MetricSourceKrakenD:
+		return "krakend"
+	case MetricSourceKuma:
+		return "kuma"
+	case MetricSourceLiteLLM:
+		return "lite_llm"
+	case MetricSourceLustre:
+		return "lustre"
+	case MetricSourceProxmox:
+		return "proxmox"
+	case MetricSourceResilience4j:
+		return "resilience4j"
+	case MetricSourceSupabase:
+		return "supabase"
+	case MetricSourceKeda:
+		return "keda"
+	case MetricSourceDuckdb:
+		return "duckdb"
 	case MetricSourceOpenTelemetryCollectorUnknown:
 		return "opentelemetry_collector_unknown"
 	case MetricSourceOpenTelemetryCollectorDockerstatsReceiver:
@@ -1028,6 +1078,36 @@ func (ms MetricSource) String() string {
 		return "opentelemetry_collector_chronyreceiver"
 	case MetricSourceOpenTelemetryCollectorCouchdbReceiver:
 		return "opentelemetry_collector_couchdbreceiver"
+	case MetricSourceServerless:
+		return "serverless"
+	case MetricSourceAwsLambdaCustom:
+		return "aws_lambda_custom"
+	case MetricSourceAwsLambdaEnhanced:
+		return "aws_lambda_enhanced"
+	case MetricSourceAwsLambdaRuntime:
+		return "aws_lambda_runtime"
+	case MetricSourceAzureContainerAppCustom:
+		return "azure_container_app_custom"
+	case MetricSourceAzureContainerAppEnhanced:
+		return "azure_container_app_enhanced"
+	case MetricSourceAzureContainerAppRuntime:
+		return "azure_container_app_runtime"
+	case MetricSourceAzureAppServiceCustom:
+		return "azure_app_service_custom"
+	case MetricSourceAzureAppServiceEnhanced:
+		return "azure_app_service_enhanced"
+	case MetricSourceAzureAppServiceRuntime:
+		return "azure_app_service_runtime"
+	case MetricSourceGoogleCloudRunCustom:
+		return "google_cloud_run_custom"
+	case MetricSourceGoogleCloudRunEnhanced:
+		return "google_cloud_run_enhanced"
+	case MetricSourceGoogleCloudRunRuntime:
+		return "google_cloud_run_runtime"
+	case MetricSourceWlan:
+		return "wlan"
+	case MetricSourceWindowsCertificateStore:
+		return "windows_certificate"
 	default:
 		return "<unknown>"
 	}
@@ -1582,6 +1662,22 @@ func CheckNameToMetricSource(name string) MetricSource {
 		return MetricSourceQuarkus
 	case "velero":
 		return MetricSourceVelero
+	case "altair_pbs_pro":
+		return MetricSourceAltairPBSPro
+	case "falco":
+		return MetricSourceFalco
+	case "krakend":
+		return MetricSourceKrakenD
+	case "kuma":
+		return MetricSourceKuma
+	case "lite_llm":
+		return MetricSourceLiteLLM
+	case "lustre":
+		return MetricSourceLustre
+	case "proxmox":
+		return MetricSourceProxmox
+	case "resilience4j":
+		return MetricSourceResilience4j
 	case "opentelemetry_collector_unknown":
 		return MetricSourceOpenTelemetryCollectorUnknown
 	case "opentelemetry_collector_dockerstatsreceiver":
@@ -1668,6 +1764,10 @@ func CheckNameToMetricSource(name string) MetricSource {
 		return MetricSourceOpenTelemetryCollectorChronyReceiver
 	case "opentelemetry_collector_couchdbreceiver":
 		return MetricSourceOpenTelemetryCollectorCouchdbReceiver
+	case "wlan":
+		return MetricSourceWlan
+	case "windows_certificate":
+		return MetricSourceWindowsCertificateStore
 	default:
 		return MetricSourceUnknown
 	}
